import logging
import json
from barix import HttpMethod

logger = logging.getLogger(__name__)

class BarixDanteApiHandler:
    """
    Use REST API to interact with Barix Dante Application
    """
    IP_ADDRESS  = "127.0.0.1"
    API_PORT    = 8890

    def __init__(self) -> None:
        pass        
    
    def __doGet(self, api_url):
        try:
            url = f"http://{self.IP_ADDRESS}:{self.API_PORT}{api_url}"
            res = HttpMethod.get(url,"")
            if res.status == 200:
                info = res.read()
                enc = res.info().get_content_charset('utf-8')
                return True,json.loads(info.decode(enc))
            else:
                logger.error(f"HTTP GET:{api_url} {res.status}:{res.reason}")
                return False,res.status
        except urllib.error.URLError as e:
            logger.error(f"HTTP GET:{api_url} {e.reason}")
        except:
            logger.error(f"HTTP GET:{api_url}")
        return False,500


    def __doPut(self, api_url, payload):
        try:
            url = f"http://{self.IP_ADDRESS}:{self.API_PORT}{api_url}"
            res = HttpMethod.put(url,payload)
            if res.status != 200:
                logger.error(f"HTTP PUT:{api_url} {res.status}:{res.reason}")
                return False
            return True
        except urllib.error.URLError as e:
            logger.error(f"HTTP PUT:{api_url} {e.reason}")
        except:
            logger.error(f"HTTP PUT:{api_url}")
        return False


    def startPlayer(self):
        """
        Start Barix Dante App Player
        When Barix Dante Application starts it waits for an order to start the player
        """
        return self.__doPut('/api/v1/start_player',"")
    

    def isPlayerReady(self):
        res = self.__doGet('/api/v1/player_ready')
        if res[0]:
            return res[1]["ready"]
        else:
            return False

    def getPlayerStats(self):
        """
        Get player statistics
        (at the moment only usefull when reading from dsoundcard => DANTE_ALSA_PLUGIN mode)
        """
        pass
    
    def setVolume(self,vol:int):
        return self.__doPut('/api/v1/volume', {"volume": vol}) 

    def getApplicationState(self):
        """
        Get player statistics and application Alive state 
        (at the moment only usefull when reading from dsoundcard => DANTE_ALSA_PLUGIN mode)
        """
        pass

    def getDanteReady(self):
        """
        Ready: All the Dante components are ready to communicate
        """
        pass

    def getDanteDeviceName(self):
        pass

    def getDanteClocking(self):
        pass

    def getDanteAudioFormat(self):
        pass

    