from logging.handlers import SysLogHandler
from barix.web.uci import getValueOfUci


class CustomSysLogHandler(SysLogHandler):
    '''
    Use this class to be able to set a custom program name
    '''
    def __init__(self, address, program_name, *args, **kwargs):
        super().__init__(address, *args, **kwargs)
        self.program_name = program_name

    def emit(self, record):
        msg = self.format(record)
        self.socket.sendto(f"<{self.facility | self.level}> {self.program_name}: {msg}".encode('utf-8'), self.address)



class SyslogHandle:

    def __init__(self) -> None:
        self.serverAddress = getValueOfUci("log", "syslog", "server")
        self.protocol = getValueOfUci("log", "syslog", "protocol")
        self.server = None
        self.port = None

        self.enabled = False
        if self.serverAddress != "":
            self.enabled = True
            ( self.server, self.port ) = self.serverAddress.split(':')
            self.port = int(self.port)

    def isEnabled(self):
        return self.enabled

    def getServerAddress(self):
        return self.serverAddress

    def getServer(self):
        return self.server

    def getPort(self):
        return self.port

    def getSyslogProtocol(self):
        return self.protocol