import re
from datetime import datetime
from barix.web.system_info import getHWTypeID, getSystemInfo
import logging

log = logging.getLogger('flask-backend')


def get_valid_licenses():
    """
    Parse device licenses and fill an array with all features to return to WebUI
    :return: An array with all features
    """
    licenses_full_info = getSystemInfo(['licenses']).get('licenses')
    print(f"licenses_full_info: {licenses_full_info}")

    valid_licenses = []
    for license_info in licenses_full_info:
        # {'name': 'core-image-barix-ipspeaker', 'status': 'active', 'issueDate': '25/07/2023', 'expireDate': '25/07/2053', 'id': '116830', 'features': 'N/A', 'signature': 'valid'}
        try:
            parsed_expire_date = datetime.strptime(license_info.get('expireDate'), "%d/%m/%Y")
            parsed_issue_date = datetime.strptime(license_info.get('issueDate'), "%d/%m/%Y")
            parsed_active = license_info.get('status').lower() == "active"
            parsed_signed = license_info.get('signature').lower() == "valid"
            current_date = datetime.now()
            # Validate image validation, active and signed
            if parsed_issue_date <= current_date <= parsed_expire_date and parsed_active and parsed_signed:
                parsed_features = license_info.get('features')
                lics = parsed_features.split(',')
                # Append lic values to licenses array
                valid_licenses += lics
        except Exception as ex:
            log.warn(f"Could not parse licenses info: {str(ex)}")

    return valid_licenses
