import os
import subprocess
import logging
from datetime import datetime, timedelta

log = logging.getLogger('flask-backend')


def interface_exists(interface_name):
    try:
        result = os.system(f"ip link show {interface_name} >/dev/null 2>&1")

        if result == 0:
            return True
        else:
            return False
    except Exception as e:
        return False


def start_nic_capture(interface, out_file):
    try:

        start_capture_script('/tmp/capture_script.py')
        # Start a capture with 5min duration or 5MB size.
        # Capture during 300 sec or 5MB
        subprocess.Popen(['/tmp/capture_script.py', out_file])

        now = datetime.now()
        later = now + timedelta(minutes=5)
        iso_date_string = later.isoformat()

        log.info(f"[start_nic_capture] Started interface \"interface\" capture | Out file is \"{out_file}\". Will be ready at {iso_date_string}")
        return f"Capture started for interface {interface} for 5 minutes or 5MB. Output will be available 5 min (after {iso_date_string})."
    except Exception as e:
        log.error(f"[start_nic_capture] {e}")
        return f"Error: {str(e)}"


def create_directory(directory_name):
    try:
        if not os.path.exists(directory_name):
            os.mkdir(directory_name)
        return True
    except Exception as e:
        print(f"Error: {e}")
        return False


def start_capture_script(script_path):

    try:
        script_content = '''#!/usr/bin/python3
# Start capture with TCPDUMP
#
# conditions to stop capture: 
# -> 5 seconds or file reached 5 MB

import subprocess
import os
import time
import sys

MAX_CAPTURE_SIZE = 5 * 1024 * 1024
MAX_CAPTURE_SECONDS = 300

file_name=sys.argv[1]

p = subprocess.Popen(["tcpdump", "-i", "eth0", "-w", file_name])

starTime = time.time()
while True:
    time.sleep(1)
    if os.path.exists(file_name):        
        if os.path.getsize(file_name) >= MAX_CAPTURE_SIZE:
            p.kill()
            break

    if time.time() - starTime >= MAX_CAPTURE_SECONDS:
        p.kill()
        break
   
print("Interface capture ended")
'''
        with open(script_path, 'w') as file:
            file.write(script_content)
        os.chmod(script_path, 0o755)
    except Exception as e:
        log.error(f"[start_nic_capture] {e}")
