import json

APP_CONFIG_FILE_PATH = "/mnt/data/app_config/application.json"


class AppConfigManager:
    _instance = None

    def __new__(cls, *args, **kwargs):
        if cls._instance is None:
            cls._instance = super().__new__(cls)
            cls._instance._file_path = APP_CONFIG_FILE_PATH
            cls._instance._data = cls._instance._load_data()
        return cls._instance

    def _load_data(self):
        try:
            with open(self._file_path, 'r') as file:
                return json.load(file)
        except FileNotFoundError:
            return {}

    def _save_data(self):
        with open(self._file_path, 'w') as file:
            json.dump(self._data, file, indent=4)

    def get_value(self, key):
        return self._data.get(key)

    def update_value(self, key, value):
        self._data[key] = value
        self._save_data()


# if __name__ == "__main__":
#     config_manager = AppConfigManager()
#
#     # Get value
#     mode = config_manager.get_value("application")["mode"]
#     print("Current mode:", mode)
#
#     # Update value
#     new_mode = "custom"
#     config_manager.update_value("application", {"mode": new_mode})
#     print("Updated mode:", config_manager.get_value("application")["mode"])
