import logging
from logging.handlers import RotatingFileHandler

from CustomSysLogHandler import CustomSysLogHandler

"""
Init logger
"""
def initLocalLogger(name, log_file_path, log_max_size, log_backup_count, debug_mode=False):
    log = logging.getLogger(name)
    if debug_mode:
        log.setLevel(logging.DEBUG)
    else:
        log.setLevel(logging.INFO)
    rotHandler = RotatingFileHandler(log_file_path, maxBytes=log_max_size, backupCount=log_backup_count)
    format1 = logging.Formatter('%(asctime)s  %(levelname)s  %(filename)s:%(lineno)s  %(message)s')
    rotHandler.setFormatter(format1)
    log.addHandler(rotHandler)


def initSyslogServerLogger(syslogServerAddr:str, syslogServerPort:int, debugMode:bool, programName:str):
    try:
        syslogHandler = CustomSysLogHandler(address=(syslogServerAddr, syslogServerPort), program_name=programName)
        if debugMode:
            levelMode = logging.DEBUG
        else:
            levelMode = logging.INFO

        logging.basicConfig(level=levelMode,handlers=[syslogHandler], format='%(asctime)s  %(levelname)8s  %(filename)26s:%(lineno)3s  %(message)s')
    except Exception as e:
        print(f"Syslog Error: {e}")