import json
import logging
from flask import Blueprint, request, Response
from barix.web.auth import login_required
from barix.web.uci import getAllConfigs, getValueOfUci
from app_config_manager import AppConfigManager

bp = Blueprint('uci_API', __name__)

log = logging.getLogger('flask-backend')


@bp.route('/api/rest/v1/ucis', methods=['GET'])
@login_required
def get_uci():
    try:
        uci_values = {}
        uci_list = request.args

        if uci_list == {}:
            log.info("Request list is empty, getting all UCIs")
            uci_list = getAllConfigs()

        log.info("Getting value of ucis: {}".format(uci_list))

        for uci_path in uci_list:
            if uci_path == "application.main_config.mode":
                uci_values[uci_path] = AppConfigManager().get_value("application")["mode"]
            else:
                path_params = uci_path.split('.')
                result = getValueOfUci(path_params[0], path_params[1], path_params[2])
                uci_values[uci_path] = result
        log.info("Returning uci values: {}".format(uci_values))
    except Exception as e:
        log.error(e)
        return Response(status=500)
    else:
        return Response(json.dumps(uci_values), status=200)
