#!/usr/bin/python3

import os
import sys
sys.path.append(os.path.dirname(os.path.abspath(__file__))+'/audio_sources')
sys.path.append(os.path.dirname(os.path.abspath(__file__))+'/utils')
import subprocess
import signal
import time
import syslog
import alsaaudio
import json
import flexa_uci
from barix.io import leds
from barix.licensing import findLicense
from GenericRestAPI import GenericRestAPI
from barix.system import get_hw_type
from barix.system import get_cpu_temp

DEFAULT_AQUISITION_CPU_TEMPERATURE = 60

def ipac_signal_handler(sig, frame):
    global stopRunning
    print("IPAC signal handler")
    stopRunning = True


def setMainVolume():
    vol = flexa_uci.uci_get('application.audio.volume')
    alsaaudio.Mixer("BARIX_MAIN").setvolume(int(vol))

def checkIpacLicense():
    found, _ = findLicense("core-image-barix-ipspeaker")
    if not found:
        found, _ = findLicense("core-image-barix-ussi-ipspeaker")
        if not found:
            found, _ = findLicense("barix-development-platform")

    if not found:
        syslog.syslog("required license is missing")
        sys.exit(1)

# --------------------------------------------------------------------------------------------------
print("""
===========================
IP Audio Client Starting...
(c) 2020 BARIX AG 
===========================
""")

syslog.openlog("IPAC")

appPath = os.path.dirname(os.path.realpath(__file__))

checkIpacLicense()

syslog.syslog("IP Audio Client Starting ...")

setMainVolume()

hwType = get_hw_type()

temp_proc = None
overTempCheck = False
if hwType == 69 or hwType == 75: #only MPA400 devices
    temp_proc = subprocess.Popen(["/usr/bin/temp-sensor-monitor.sh"], shell=False)
    overTempCheck = True

mode = "standard" #default app mode
if os.path.isfile("/mnt/data/app_config/application.json"):
    with open("/mnt/data/app_config/application.json") as f:
        appCfg = json.load(f)
        if "application" in appCfg and "mode" in appCfg["application"] :
            mode = appCfg["application"]["mode"]

if mode == 'aes67':
    proc = subprocess.Popen(["/usr/bin/python3", f"{appPath}/run_aes67.py", str(hwType)], shell=False)
    syslog.syslog("Running AES67 Mode")
elif mode =="dante":
    proc = subprocess.Popen(["/usr/bin/python3", f"{appPath}/run_dante-exclusive.py", str(hwType)], shell=False)
    syslog.syslog("Running Dante Exclusive Mode")
else :
    proc = subprocess.Popen(["/usr/bin/python3", f"{appPath}/run_ipspeaker.py", str(hwType)], shell=False)
    syslog.syslog("Running Standard Mode")

signal.signal(signal.SIGINT, ipac_signal_handler)
signal.signal(signal.SIGTERM, ipac_signal_handler)

api = GenericRestAPI(50555)
led = leds.IpamLed("led1")
led.set("green")
led1StatusGreen = True

stopRunning = False

tempCount = DEFAULT_AQUISITION_CPU_TEMPERATURE
while not stopRunning:
    if hwType == 69 or hwType == 75:  # only MPA400 devices
        try:
            res = api.get('/api/amp/over_temp')
            data = json.dumps(res)
            data = json.loads(data)
            otw = data['over_temp']
            if otw == 1 and led1StatusGreen:
                syslog.syslog("Global overtemperature warning!")
                led.set("yellow",blink=True)
                led1StatusGreen = False
            elif otw == 0 and not led1StatusGreen:
                syslog.syslog("No global overtemperature warning")
                led.set("green")
                led1StatusGreen = True
        except:
            syslog.syslog("Error trying to check MPA400 Amp over temperature")
    if tempCount > DEFAULT_AQUISITION_CPU_TEMPERATURE:
        tempCount = 0
        syslog.syslog(f"cpu temperature: {get_cpu_temp()}")

    # if ipac proc terminates or got defunct the caller process must end so that barix-wd may restart all
    if proc.poll() is not None:
        syslog.syslog("IPAC app no longer running")
        stopRunning = True
    
    time.sleep(1)
    tempCount += 1

if temp_proc is not None:
    temp_proc.terminate()
    temp_proc.wait()
proc.terminate()
proc.wait()
