import logging
import time
import baco
from threading import Thread

logger = logging.getLogger('ipspeaker')

class RtpOutPlayer:
    def __init__(self, url, pcmpDev):
        self.url = url
        self.pcmpDev = pcmpDev
        self.player = None
        self.playerConnectThread = None

    def startPlayer(self):
        logger.info("Create RTP Low Latency Mode player ")
        self.player = baco.SimplePlayer(self.url, self.pcmpDev,44100, baco.CONSTDELAY)
        logger.info("Using buffer:500ms, ready threshold: 50ms")
        self.player.setInputFifoDuration(0)
        self.player.setOutputFifoDuration(500)
        self.player.setReadyThreshold(50)
        self.player.setMaxDelta(30)
        self.player.setCallback(self.__checkStateCallback)
        logger.info(f"Start rtp player: url: {self.url}, audio dev: {self.pcmpDev}")
        self.__connect()

    def connect(self):
        self.playerConnectThread = Thread(target=self.__connect())
        self.playerConnectThread.daemon = True
        self.playerConnectThread.start()

    def stopPlayer(self):
        if self.player is not None:
            logger.info("Stop player")
            self.player.disconnect()

    def __connect(self):
            logger.info("RTP player -> Connect")
            self.player.connect()
                                        
    def __checkStateCallback(self, alive):
        logger.info(f"Rtp player alive: {alive}")
        if alive:
            self.connect()        
