import logging
from logging.handlers import RotatingFileHandler, SysLogHandler
import socket

#implement a local rotating log with n log files maximum
def initLocalLogger(logFileName:str, maxFileSize:int, numBackups:int, debugMode:bool):
    rotHandler = RotatingFileHandler(logFileName, maxBytes=maxFileSize, backupCount=numBackups)
    if debugMode:
        levelMode = logging.DEBUG
    else:
        levelMode = logging.INFO
    logging.basicConfig(level=levelMode,handlers=[rotHandler], format='%(asctime)s  %(levelname)8s  %(filename)26s:%(lineno)3s  %(message)s')


class CustomSysLogHandler(SysLogHandler):
    '''
    Use this class to be able to set a custom program name
    '''
    def __init__(self, address, program_name, *args, **kwargs):
        super().__init__(address, *args, **kwargs)
        self.program_name = program_name

    def emit(self, record):
        msg = self.format(record)
        self.socket.sendto(f"<{self.facility | self.level}> {self.program_name}: {msg}".encode('utf-8'), self.address)

def initSyslogServerLogger(syslogServerAddr:str, syslogServerPort:int, debugMode:bool, programName:str):
    try:
        syslogHandler = CustomSysLogHandler(address=(syslogServerAddr, syslogServerPort), program_name=programName)
        if debugMode:
            levelMode = logging.DEBUG
        else:
            levelMode = logging.INFO

        logging.basicConfig(level=levelMode,handlers=[syslogHandler], format='%(asctime)s  %(levelname)8s  %(filename)26s:%(lineno)3s  %(message)s')
    except Exception as e:
        print(f"Syslog Error: {e}")