import logging
import subprocess
import alsaaudio
from . import flexa_uci

logger = logging.getLogger('ipspeaker')

class AudioMixers:
    """
    Set IPAC Audio Mixer settings
    """

    def __init__(self) -> None:
        self.audioInput = flexa_uci.uci_get("application.audio.input")
        self.micInGain = flexa_uci.uci_get("application.audio.micin_gain")
        self.lineInGain = flexa_uci.uci_get("application.audio.linein_gain")
        self.mute = flexa_uci.uci_get('application.audio.muted')
        self.mainVolume = int(flexa_uci.uci_get('application.audio.volume'))
        logger.info(f"Audio Input: {self.audioInput}, MIC Gain:{self.micInGain}, Line-In Gain:{self.lineInGain}")
        logger.info(f"Mute: {self.mute}, mainVolume: {self.mainVolume}")

    def getAudioInput(self):
        return self.audioInput

    def disableAllCap(self):
        logger.info("Disable audio capture")
        self.__setMixerParam("ADC Gain", "0dB")
        self.__setMixerParam("Mic1", "nocap")
        self.__setMixerParam("Line In", "nocap")

    def enableLineInCap(self):
        logger.info("Enable Line-In capture and disable Mic capture")
        self.__setMixerParam("Line In", "cap")
        self.__setMixerParam("Line In", f"{self.lineInGain}%")
        self.__setMixerParam("ADC Gain", "0dB")
        self.__setMixerParam("Mic1", "nocap")

    def enableMicInCapture(self):
        logger.info("Enable Mic Capture and disable Line-In capture")
        self.__setMixerParam("Mic1", "cap")
        self.__setMixerParam("Mic1", "4.5dB")
        self.__setMixerParam("Mic1 Boost", str(str(self.micInGain) + "dB"))
        self.__setMixerParam("Line In", "nocap")

    def __setMixerParam(self, param, value):
        p = subprocess.Popen("amixer -q -c 2 -- sset " + "\'" + param + "\'" + " \'" + value + "\'", shell=True)
        p.wait()

    def initChannelMixers(self):
        logger.info("Initialize all channel mixers")
        alsaaudio.PCM(device='channel1')
        alsaaudio.PCM(device='channel2')
        alsaaudio.PCM(device='channel3')
        alsaaudio.PCM(device='channel4')
        alsaaudio.PCM(device='channel5')
        alsaaudio.PCM(device='channel11')
        alsaaudio.PCM(device='channel12')

    def setMainMixerVolume(self):
        mainVolumeCtl = alsaaudio.Mixer("BARIX_MAIN")
        if self.mute == 'true':
            mainVolumeCtl.setvolume(0)
            logger.info("Set Main mixer volume: 0")
        else:
            mainVolumeCtl.setvolume(self.mainVolume)
            logger.info(f"Set Main mixer volume: {self.mainVolume}")