#!/bin/sh

# Write system information to syslog
# -> load average
# -> memory information
# -> process info

NUM_PROC=10
LOG_PERIOD=60

#set syslog configuration file according UCI log configuration
set_syslog_configuration() {
    # Check if the UCI entry exists
    UCI_LOG_SERVER=$(uci get log.syslog.server 2>/dev/null)

    if [ $? -eq 0 ]; then
        # UCI entry exists, set DESTINATION to remote and REMOTE to the value from UCI
        DESTINATION="remote"
        REMOTE="$UCI_LOG_SERVER"
    else
        # UCI entry does not exist, set DESTINATION to file
        DESTINATION="file"
        REMOTE=""
    fi

    # Update the syslog-startup.conf file
    # Modify DESTINATION
    sed -i "s/^DESTINATION=.*/DESTINATION=$DESTINATION/" /etc/syslog-startup.conf

    # Modify REMOTE if UCI entry exists
    if [ "$DESTINATION" == "remote" ]; then
        sed -i "s/^REMOTE=.*/REMOTE=$REMOTE/" /etc/syslog-startup.conf
    fi 
}


# Function to log system information
log_system_info() {
    # load average
    LOAD_AVG=$(cat /proc/loadavg | awk '{print $1, $2, $3}')

    logger "Load Average: $LOAD_AVG"

    # memory information
    MEM_INFO=$(free -m | awk 'NR==2{printf "Total: %sMB, Free: %sMB, Used: %sMB\n", $2, $4, $3}')

    logger "Memory Info: $MEM_INFO"

}

set_syslog_configuration

# send logs every LOG_PERIOD (seconds)
while true; do
    log_system_info
    sleep $LOG_PERIOD
done

